"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var logger_1 = require("../logger");
var access_control_with_organizations_authorization_1 = require("./access-control-with-organizations.authorization");
var Q = require('q');
describe('[Access Control]', function () {
    var promisedAcessControl;
    var newVideo, myVideo, videoFromThirdPary, adminUser, normalUser, organizationManager, organizationOtherRole, organizationMember, guestUser;
    var queryMock;
    promisedAcessControl = access_control_with_organizations_authorization_1.crudAccessControlWithOrgRolesFactory('video', [
        { role: 'guest', resource: 'catalog', action: 'read:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'create:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'read:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'update:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'delete:any', attributes: ['*'] },
        { role: 'user', resource: 'video', action: 'read:own', attributes: ['*'] },
        { role: '$organization:member', resource: 'video', action: 'read:own', attributes: ['*'] },
        { role: '$organization:member', resource: 'video', action: 'update:own', attributes: ['*'] },
        { role: '$organization:manager', resource: 'video', action: 'read:any', attributes: ['*'] },
        { role: '$organization:manager', resource: 'video', action: 'create:own', attributes: ['*'] },
        { role: '$organization:manager', resource: 'video', action: 'update:own', attributes: ['*'] },
        { role: '$organization:manager', resource: 'video', action: 'delete:own', attributes: ['*'] }
    ]);
    organizationManager = {
        _id: '001',
        roles: ['user', '$organization:vert:manager'],
    };
    organizationOtherRole = {
        _id: '0010',
        roles: ['user'],
        organization: {
            ref: { code: 'vert' },
            role: 'other1'
        }
    };
    organizationMember = {
        _id: '002',
        roles: ['user', '$organization:vert:member'],
    };
    normalUser = {
        _id: '100',
        roles: ['user']
    };
    it('should organization manager be grant read any', function () {
        return promisedAcessControl
            .then(function (accessControll) {
            return accessControll.check(organizationManager, 'read');
        })
            .then(function (grant) {
            logger_1.default.trace('asserting permission attrs');
            chai_1.expect(grant.granted).to.equal(true);
            chai_1.expect(grant.type).to.equal('any');
        });
    });
    it('should organization manager be grant create access', function () {
        return promisedAcessControl
            .then(function (accessControll) {
            return accessControll.check(organizationManager, 'create');
        })
            .then(function (grant) {
            logger_1.default.trace('asserting permission attrs');
            chai_1.expect(grant.granted).to.equal(true);
            chai_1.expect(grant.type).to.equal('own');
            chai_1.expect(grant.ownerTypes).to.include.members(['organization']);
        });
    });
    it('should organization member be grant update access', function () {
        return promisedAcessControl
            .then(function (accessControll) {
            return accessControll.check(organizationManager, 'update');
        })
            .then(function (grant) {
            logger_1.default.trace('asserting permission attrs');
            chai_1.expect(grant.granted).to.equal(true);
            chai_1.expect(grant.type).to.equal('own');
            chai_1.expect(grant.ownerTypes).to.include.members(['organization']);
        });
    });
    it('should organization member not be grant read write access', function () {
        return promisedAcessControl
            .then(function (accessControll) {
            return accessControll.check(organizationMember, 'create');
        })
            .then(function (grant) {
            logger_1.default.trace('asserting permission attrs');
            chai_1.expect(grant.granted).to.equal(false);
        });
    });
    it('should organization member be grant read access for user:own and organization:own', function () {
        return promisedAcessControl
            .then(function (accessControll) {
            return accessControll.check(organizationMember, 'read');
        })
            .then(function (grant) {
            logger_1.default.trace('asserting permission attrs');
            chai_1.expect(grant.granted).to.equal(true);
            chai_1.expect(grant.type).to.equal('own');
            chai_1.expect(grant.ownerTypes).to.include.members(['organization', 'user']);
        });
    });
});
