'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var authentication_service_1 = require("../security/authentication.service");
var authorization_utils_1 = require("../security/authorization.utils");
var logger_1 = require("../logger");
var createError = require('http-errors');
function checkAuthorization(op, req) {
    return function (entity) {
        logger_1.default.debug(entity);
        logger_1.default.debug('verifying authorization of "' + op + '" for user ' + (req.user ? req.user.name : 'unauthenticated'));
        if (entity.userId && (!authentication_service_1.isAuthenticated(req) || entity.userId !== req.user._id)) {
            throw createError(403, 'userId of loggedin user different from entity owner');
        }
        return entity; //ok
    };
}
exports.checkAuthorization = checkAuthorization;
function restrictByUser(req) {
    return function (query) {
        if (authorization_utils_1.hasRole(req.user, 'admin')) {
            return query;
        }
        query.where("userId").eq(req.user._id);
    };
}
exports.restrictByUser = restrictByUser;
