'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Authenticator.
 */
var logger_1 = require("../logger");
var request = require('request');
var createError = require('http-errors');
var Q = require('q');
var _ = require('lodash');
/**
 * Attaches the user object to the request if authenticated
 * Otherwise returns 401
 */
function ensureIsAuthenticated(req, res, next) {
    authenticate(req, res)
        .then(function () {
        next();
    })
        .catch(function (err) {
        next(createError(401, err));
    })
        .done();
}
exports.ensureIsAuthenticated = ensureIsAuthenticated;
;
/**
 * Attaches the user object to the request if authenticated
 * Otherwise continue silently
 */
function authenticatedIfCredentialProvided(req, res, next) {
    if (!req.headers || !req.headers.authorization) {
        next();
    }
    else {
        authenticate(req, res)
            .then(function () {
            next();
        })
            .catch(function (err) {
            next(createError(401, err));
        })
            .done();
    }
}
exports.authenticatedIfCredentialProvided = authenticatedIfCredentialProvided;
;
function authenticate(req, res) {
    return queryMe(req)
        .then(function (user) {
        req.user = user;
        return user;
    });
}
exports.authenticate = authenticate;
function queryMe(req) {
    var uri = process.env.AUTHENTICATOR_URI ||
        req.protocol + '://' + req.get('host'); //same server
    var url = uri + '/api/users/me';
    return Q.nfcall(request.get, {
        url: url,
        headers: { authorization: req.headers.authorization },
        json: true,
    })
        .then(function (data) {
        var response = data[0];
        var body = data[1];
        if (response.statusCode >= 300) {
            logger_1.default.warn("[access denied] Auth server url: " + url);
            logger_1.default.warn("[access denied] Auth server response: \n " + JSON.stringify(body));
            throw "Can not authenticate user.Check server for log.";
        }
        return body;
    });
}
/**
 * #####  UTILS  #####
 */
/**
 * Checks if request is authenticated
 */
function isAuthenticated(req) {
    return !_.isNil(req.user);
}
exports.isAuthenticated = isAuthenticated;
/**
 * Checks if the user role meets the minimum requirements of the route
 */
function getUserInfomations(email) {
    // TODO: Need to auth server-server
    return Q.nfcall(request.get, {
        url: process.env.AUTHENTICATOR_URI + "/api/users/email/" + email,
        // headers: { authorization: req.headers.authorization },
        json: true,
    })
        .then(function (data) {
        var response = data[0];
        var body = data[1];
        if (response.statusCode >= 300)
            throw 'Can not get user infos from authenticator server. Reason: ' + JSON.stringify(body);
        return body;
    })
        .then(function (user) {
        return user;
    })
        .catch(function (err) {
        logger_1.default.error("Can not get user infos from authenticator server. Reason: " + err);
    });
}
exports.getUserInfomations = getUserInfomations;
// check configuration
(function () {
    if (process.env.AUTHENTICATOR_URI)
        logger_1.default.debug('using ' + process.env.AUTHENTICATOR_URI + ' to authentication');
    else
        logger_1.default.error('no AUTHENTICATOR_URI setted in the environment');
})();
